Welcome to LLMScout's documentation!
================================

LLMScout is an LLM-powered tool for discovering and analyzing research papers.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   api
   examples
   contributing
   changelog
